# SubmitDataQueryRequestOutputTarget

Set this field to `S3`. 

## Enum

* `S3` (value: `'S3'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


